@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.6 2004/01/08 06:54:01 komatsu Exp $
+# $Id: prime.rb,v 1.2.2.1 2003/12/13 22:25:27 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -13,37 +13,29 @@ require 'prime/prime-config'
 require 'prime/taiyaki'
 require 'suikyo/suikyo'
 
-PRIME_CONFIGFILE_GLOBAL = File::join2(PRIME_CONFIG_DIR,  "Custom_prime.rb")
-PRIME_CONFIGFILE_LOCAL  = (ENV['PRIME_CONFIG'] or 
-                             File::join2(PRIME_USER_DIR, "Custom_prime.rb"))
-
 class Prime
   include Debug
 
   def initialize (engine_files = nil)
     @debug_mode = false
     Dir::ensure(PRIME_USER_DIR)
-    initialize_rc()
+    initialize_rc
 
-    @input = PrimeInput.new()
+    @input = PrimeInput.new
     @engines = init_engines(engine_files)
   end
 
   def initialize_rc
-    if File::exist?(PRIME_CONFIGFILE_GLOBAL) == false then
-      $stderr.puts "PRIME-ERROR:"
-      $stderr.puts "  The file Custom_prime.rb is not found."
-      $stderr.puts "  You might need to install Custom_prime.rb by"
-      $stderr.puts "  'make install-etc'.  Sorry for your inconvenience."
-      Kernel::exit()
-    end
+    global_config_file = File::join2(PRIME_CONFIG_DIR, 'Custom_prime.rb')
+    local_config_file  =
+      (ENV['PRIME_CONFIG'] or File::join2(PRIME_USER_DIR, 'Custom_prime.rb'))
 
-    load(PRIME_CONFIGFILE_GLOBAL)
-    if FileTest::exist?(PRIME_CONFIGFILE_LOCAL) then
-      load(PRIME_CONFIGFILE_LOCAL)
+    load(global_config_file)
+    if FileTest::exist?(local_config_file) then
+      load(local_config_file)
     else
-      Dir::ensure(File::dirname(PRIME_CONFIGFILE_LOCAL))
-      `cp #{PRIME_CONFIGFILE_GLOBAL} #{PRIME_CONFIGFILE_LOCAL}`
+      Dir::ensure(File::dirname(local_config_file))
+      `cp #{global_config_file} #{local_config_file}`
     end
   end
 
@@ -85,12 +77,6 @@ class Prime
     @engines.command(:close)
   end
 
-  def refresh
-    initialize_rc()
-    @input = PrimeInput.new()
-#    @engines.command(:refresh)
-  end
-
   def get_env (key)
     return PRIME_ENV[key]
   end
@@ -99,10 +85,6 @@ class Prime
     return @input.label(pattern)
   end
 
-  def preedit_convert_input (pattern)
-    return @input.convert_input(pattern).join("\t")
-  end
-
   def set_context (context)
     @input.set_context(context)
   end
@@ -163,13 +145,7 @@ class PrimeInput
   end
 
   def initialize_suikyo
-    if PRIME_ENV['suikyo_use_cache'] then
-      threshold_time = [File::mtime(File::expand_path(__FILE__)),
-                        File::mtime(PRIME_CONFIGFILE_GLOBAL),
-                        File::mtime(PRIME_CONFIGFILE_LOCAL)].max
-    else
-      threshold_time = Time.new()
-    end
+    threshold_time = PRIME_ENV['suikyo_use_cache'] ? nil : Time.new
     suikyo = Marshal::init_file(File::join2(PRIME_USER_DIR, "suikyo.rbo"),
 				threshold_time) {
       suikyo = Suikyo.new
@@ -191,11 +167,6 @@ class PrimeInput
     end    
   end
 
-  def convert_input (string)
-    (conversion, pending, node) = @suikyo.convert_internal(string)
-    return [conversion, pending]
-  end
-
   def set (input, context = nil)
     @original = input
     (@base, @expands) = @suikyo.expand(input)
