@@ -1,5 +1,5 @@
 # session.rb
-# $Id: session.rb,v 1.3 2003/12/31 09:21:23 komatsu Exp $
+# $Id: session.rb,v 1.1.1.1 2003/05/28 17:48:18 komatsu Exp $
 #
 # Copyright (C) 2001 Satoru Takabayashi <satoru@namazu.org>
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
@@ -36,17 +36,15 @@ module PogemoServer
       @pogemo  = pogemo
       @name    = "no name"
       @id      = "no ID"
-      @debug   = false
+      @debug = false
       @command_table = Hash.new
       init_command_table
-    end
-    attr_accessor :name
 
-    def set_debug (filename)
-      @debug    = true
-      @debug_io = File::open(filename, "w")
-      @debug_io.chmod(0600) if @debug_io::stat.owned?
+      ## FIXME: Here is not a suitable location to open a logging file.
+      ## FIXME: <komatsu@taiyaki.org> (2003-12-16)
+      @debug_io = open(ENV['HOME'] + "/.prime/debug_" + $$.to_s + ".log", "w")
     end
+    attr_accessor :debug, :name
 
     def init_command_table
       add_command(:close, [], "close the connection")
@@ -115,6 +113,8 @@ module PogemoServer
     def start
       while line = @in.gets do
 	logging(line)
+#	logging(line) if @debug
+#	chunks = line.gsub(/[\r\n]/, "").split("\t+")
 	chunks = line.gsub(/[\r\n]/, "").split("\t")
 	if chunks.length > 0 then
 	  name = chunks.shift.intern
@@ -126,29 +126,22 @@ module PogemoServer
     end
 
     def logging(line)
-      if @debug then
-        line.chomp()
-        @debug_io.puts(line)
-        @debug_io.flush()
-      end
+      line.chomp()
+      @debug_io.puts(line)
+      @debug_io.flush()
     end
   end
 
   class Server
     def initialize (pogemo)
       @pogemo = pogemo
-      @debug  = false
-      @logfile = nil
+      @debug = false
     end
+    attr_accessor :debug
 
     public
     def accept
     end
-
-    def set_debug (logfile)
-      @debug   = true
-      @logfile = logfile
-    end
   end
 
   class UnixSocketServer < Server
@@ -163,9 +156,7 @@ module PogemoServer
 	t = Thread.new {
 	  s = socket
 	  session = Session.new(@pogemo, s, s)
-          if @debug then
-            session.set_debug(@logfile)
-          end
+	  session.debug = @debug
 	  session.start
 	}
 	t.abort_on_exception = true
@@ -185,9 +176,7 @@ module PogemoServer
 	t = Thread.new {
 	  s = socket
 	  session = Session.new(@pogemo, s, s)
-          if @debug then
-            session.set_debug(@logfile)
-          end
+	  session.debug = @debug
 	  session.start
 	}
 	t.abort_on_exception = true
@@ -203,9 +192,7 @@ module PogemoServer
 
     def accept
       session = Session.new(@pogemo, $stdin, $stdout)
-      if @debug then
-        session.set_debug(@logfile)
-      end
+      session.debug = @debug
       session.start
     end
   end
